==> style-react-1.0.1115.tgz: package/esm/AmauiThemeProvider/AmauiThemeProvider.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
const _excluded = ["value", "children"];
import React from 'react';
import is from '@amaui/utils/is';
import merge from '@amaui/utils/merge';
import hash from '@amaui/utils/hash';
import { AmauiTheme } from '@amaui/style';
import AmauiThemeContext from './AmauiThemeContext';
import useAmauiTheme from './useAmauiTheme';

const resolveValue = value => {
  const toFilterOut = ['id', 'element', 'subscriptions'];
  const valueNew = {};
  Object.keys(value).filter(item => toFilterOut.indexOf(item) === -1).forEach(item => valueNew[item] = value[item]);
  return valueNew;
};

const AmauiThemeProvider = /*#__PURE__*/React.forwardRef((props, ref) => {
  const [init, setInit] = React.useState(false);

  const {
    value: valueLocal = {},
    children
  } = props,
        other = _objectWithoutProperties(props, _excluded);

  const refs = {
    root: React.useRef()
  };
  const valueParent = useAmauiTheme() || {};
  const [value, setValue] = React.useState(() => new AmauiTheme(merge(resolveValue(is('function', valueLocal) ? valueLocal(valueParent) : valueLocal), resolveValue(valueParent), {
    copy: true
  })));
  React.useEffect(() => {
    if (refs.root.current) {
      const amauiTheme = new AmauiTheme(value, refs.root.current);
      amauiTheme.id = value.id;
      amauiTheme.subscriptions = value.subscriptions; // Init

      setValue(amauiTheme);
      setInit(true);
    }
  }, []);
  React.useEffect(() => {
    if (init) {
      var _refs$root;

      value.update(merge(resolveValue(is('function', valueLocal) ? valueLocal(valueParent) : valueLocal), resolveValue(valueParent), {
        copy: true
      }));
      const amauiTheme = new AmauiTheme(value, (_refs$root = refs.root) === null || _refs$root === void 0 ? void 0 : _refs$root.current);
      amauiTheme.id = value.id;
      amauiTheme.subscriptions = value.subscriptions; // Init

      setValue(amauiTheme);
    }
  }, [hash(resolveValue(valueLocal)), hash(resolveValue(valueParent))]);

  const update = updateValue => {
    if (updateValue !== undefined) {
      var _refs$root2;

      // Update
      value.update(updateValue);
      const amauiTheme = new AmauiTheme(value, (_refs$root2 = refs.root) === null || _refs$root2 === void 0 ? void 0 : _refs$root2.current);
      amauiTheme.id = value.id;
      amauiTheme.subscriptions = value.subscriptions; // Init

      setValue(amauiTheme);
      return value;
    }
  }; // Update method


  value.updateWithRerender = update;
  return /*#__PURE__*/React.createElement(AmauiThemeContext.Provider, {
    value: value
  }, /*#__PURE__*/React.createElement("div", _extends({
    ref: item => {
      refs.root.current = item;
      if (ref !== null && ref !== void 0 && ref.current) ref.current = item;
    }
  }, other), children));
});
export default AmauiThemeProvider;

==> style-react-1.0.1119.tgz: package/esm/AmauiThemeProvider/AmauiThemeProvider.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
const _excluded = ["root", "value", "children"];
import React from 'react';
import is from '@amaui/utils/is';
import merge from '@amaui/utils/merge';
import hash from '@amaui/utils/hash';
import isEnvironment from '@amaui/utils/isEnvironment';
import { AmauiTheme } from '@amaui/style';
import AmauiThemeContext from './AmauiThemeContext';
import useAmauiTheme from './useAmauiTheme';

const resolveValue = value => {
  const toFilterOut = ['id', 'element', 'subscriptions'];
  const valueNew = {};
  Object.keys(value).filter(item => toFilterOut.indexOf(item) === -1).forEach(item => valueNew[item] = value[item]);
  return valueNew;
};

const AmauiThemeProvider = /*#__PURE__*/React.forwardRef((props, ref) => {
  const [init, setInit] = React.useState(false);

  const {
    root = false,
    value: valueLocal = {},
    children
  } = props,
        other = _objectWithoutProperties(props, _excluded);

  const refs = {
    root: React.useRef()
  };
  const valueParent = useAmauiTheme() || {};
  const [value, setValue] = React.useState(() => new AmauiTheme(merge(resolveValue(is('function', valueLocal) ? valueLocal(valueParent) : valueLocal), resolveValue(valueParent), {
    copy: true
  })));
  React.useEffect(() => {
    if (refs.root.current) {
      const amauiTheme = new AmauiTheme(value, refs.root.current);
      amauiTheme.id = value.id;
      amauiTheme.subscriptions = value.subscriptions; // Init

      setValue(amauiTheme);
      setInit(true);
    }
  }, []);
  React.useEffect(() => {
    if (init) {
      var _refs$root;

      value.update(merge(resolveValue(is('function', valueLocal) ? valueLocal(valueParent) : valueLocal), resolveValue(valueParent), {
        copy: true
      }));
      const amauiTheme = new AmauiTheme(value, (_refs$root = refs.root) === null || _refs$root === void 0 ? void 0 : _refs$root.current);
      amauiTheme.id = value.id;
      amauiTheme.subscriptions = value.subscriptions; // Init

      setValue(amauiTheme);
    }
  }, [hash(resolveValue(valueLocal)), hash(resolveValue(valueParent))]);

  const update = updateValue => {
    if (updateValue !== undefined) {
      var _refs$root2;

      // Update
      value.update(updateValue);
      const amauiTheme = new AmauiTheme(value, ((_refs$root2 = refs.root) === null || _refs$root2 === void 0 ? void 0 : _refs$root2.current) || isEnvironment('browser') && window.document.body);
      amauiTheme.id = value.id;
      amauiTheme.subscriptions = value.subscriptions; // Init

      setValue(amauiTheme);
      return value;
    }
  }; // Update method


  value.updateWithRerender = update;

  if (root) {
    return /*#__PURE__*/React.createElement(AmauiThemeContext.Provider, {
      value: value
    }, /*#__PURE__*/React.createElement("div", _extends({
      ref: item => {
        refs.root.current = item;
        if (ref !== null && ref !== void 0 && ref.current) ref.current = item;
      }
    }, other), children));
  }

  return /*#__PURE__*/React.createElement(AmauiThemeContext.Provider, {
    value: value
  }, children);
});
export default AmauiThemeProvider;
